==> agent-2.2.2-sources.jar: org/nhindirect/stagent/mail/notifications/NotificationType.java <==
/* 
Copyright (c) 2010, NHIN Direct Project
All rights reserved.

Authors:
   Umesh Madan     umeshma@microsoft.com
   Greg Meyer      gm2552@cerner.com
 
Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer 
in the documentation and/or other materials provided with the distribution.  Neither the name of the The NHIN Direct Project (nhindirect.org). 
nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS 
BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE 
GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF 
THE POSSIBILITY OF SUCH DAMAGE.
*/

package org.nhindirect.stagent.mail.notifications;

import org.apache.jsieve.mailet.mdn.DispositionType;

/**
 * Indicates what this disposition notification means.
 * <p>
 * <a href="http://tools.ietf.org/html/rfc3798">RFC 3798</a>, Disposition types, 3.2.6.2, includes type (processed) mentioned in document but
 * not listed in grammar.
 * @author Greg Meyer
 * @author Umesh Madan
 */
public enum NotificationType implements DispositionType 
{
	/**
	 * Indicates message has been received but not displayed to user.
	 */
	Processed
	{
	    public String toString() 
	    {
	    	return NotificationHelper.asString(this);
	    }
	},
	
	/**
	 * Indicates message has been displayed to user (does not imply the message was read, understood, etc.)
	 */
	Displayed
	{
	    public String toString() 
	    {
	    	return NotificationHelper.asString(this);
	    }
	},
	
	/**
	 * Indicates message was deleted.
	 */
	Deleted
	{
	    public String toString() 
	    {
	    	return NotificationHelper.asString(this);
	    }
	},	
	
	/**
	 * Indicates message was dispatched.
	 */
	Dispatched
	{
	    public String toString() 
	    {
	    	return NotificationHelper.asString(this);
	    }
	},	
	
	/**
	 * Indicates message was denied.
	 */
	Denied
	{
	    public String toString() 
	    {
	    	return NotificationHelper.asString(this);
	    }
	},	
	
	/**
	 * Indicates message was in error.
	 */
	Error
	{
	    public String toString() 
	    {
	    	return NotificationHelper.asString(this);
	    }
	}		
}

==> agent-8.0.0-sources.jar: org/nhindirect/stagent/mail/notifications/NotificationType.java <==
/* 
Copyright (c) 2010, NHIN Direct Project
All rights reserved.

Authors:
   Umesh Madan     umeshma@microsoft.com
   Greg Meyer      gm2552@cerner.com
 
Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer 
in the documentation and/or other materials provided with the distribution.  Neither the name of the The NHIN Direct Project (nhindirect.org). 
nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS 
BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE 
GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF 
THE POSSIBILITY OF SUCH DAMAGE.
*/

package org.nhindirect.stagent.mail.notifications;

/**
 * Indicates what this disposition notification means.
 * <p>
 * <a href="http://tools.ietf.org/html/rfc3798">RFC 3798</a>, Disposition types, 3.2.6.2, includes type (processed) mentioned in document but
 * not listed in grammar.
 * @author Greg Meyer
 * @author Umesh Madan
 */
public enum NotificationType
{
	/**
	 * Indicates message has been received but not displayed to user.
	 */
	Processed
	{
	    public String toString() 
	    {
	    	return NotificationHelper.asString(this);
	    }
	},
	
	/**
	 * Indicates message has been displayed to user (does not imply the message was read, understood, etc.)
	 */
	Displayed
	{
	    public String toString() 
	    {
	    	return NotificationHelper.asString(this);
	    }
	},
	
	/**
	 * Indicates message was deleted.
	 */
	Deleted
	{
	    public String toString() 
	    {
	    	return NotificationHelper.asString(this);
	    }
	},	
	
	/**
	 * Indicates message was dispatched.
	 */
	Dispatched
	{
	    public String toString() 
	    {
	    	return NotificationHelper.asString(this);
	    }
	},	
	
	/**
	 * Indicates message was denied.
	 */
	Denied
	{
	    public String toString() 
	    {
	    	return NotificationHelper.asString(this);
	    }
	},	
	
	/**
	 * Indicates message was in error.
	 */
	Error
	{
	    public String toString() 
	    {
	    	return NotificationHelper.asString(this);
	    }
	}, 
    
    /**
     * Negative delivery notification message is issued by an STA when delivery to a destination 
     * has failed or is considered to have failed.
     */
    Failed
    {
        public String toString() 
        {
            return NotificationHelper.asString(this);
        }
    }   	
}
